Welcome to django-wikiwikiweb's documentation!
==============================================

**Django WikiWikiWeb** is a Python + Django Wiki app. It is heavily inspired by `the original Wiki <https://wiki.c2.com/?>`_ built by Ward Cunningham, whilst not quite being a `WikiClone <https://wiki.c2.com/?WikiWikiClones>`_. It contains a few extra, modern features, integrates with the Django admin, and will not be recreating the `controversial <https://news.ycombinator.com/item?id=8983158>`_ newer JavaScript/single-page interface.


.. note::

   This project is under active development, as is the documentation. Keep an eye on the `django-wikiwikiweb GitHub pages <https://github.com/simonharris/django-wikiwikiweb>`_ for source code and updates.

Contents
--------

.. toctree::

   installation
   templatetags
